part of oche;

const _DEFAULT_PAGE = 'index.html';
final _libLogger = new Logger('oche');
_Router _router;

/**
 * Creates the application [_Router] by building a [_RouteTrie]
 * from the [routeMap] and passing it to a new instance of [_Router].
 */
void _createRouter(Map<String, Type> routeMap) {

  var routeTrie = new _RouteTrie()
        ..build(routeMap);

    _router = new _Router(routeTrie);

}

/**
 * Returns a [VirtualDirectory] to serve static files from the given [rootPath].
 */
VirtualDirectory _getVirtualDirectory(String rootPath) {

  VirtualDirectory virtualDir = new VirtualDirectory(rootPath);

      virtualDir.allowDirectoryListing = true;

      /*
       * We add a directory handler that serves _DEFAULT_PAGE
       * files when directories are requested.
       */
      virtualDir.directoryHandler = (directory, request) {

          var indexUri = new Uri.file(directory.path).resolve(_DEFAULT_PAGE);
          var indexFile = new File(indexUri.toFilePath());

          virtualDir.serveFile(indexFile, request);

      };

      return virtualDir;
}

/**
 * Starts the server on the given [host] and [port].
 * Also takes a [staticFilesRoot] to create a [VirtualDirectory].
 */
void _startServer(String host, int port, String staticFilesRoot) {

  HttpServer.bind(host, port).then((HttpServer server) {

    var virtualDirectory = _getVirtualDirectory(staticFilesRoot);
    var requestHandler = new _RequestHandler(virtualDirectory);

    server.listen(requestHandler);

    _libLogger.info('HttpServer listening on $host:$port.');

  });


}